@@ -7,7 +7,7 @@ Desc: HTTP 测试
 import requests
 import pandas as pd
 
-url = "http://127.0.0.1:8080/api/fund_em_lcx_rank"
+url = "http://127.0.0.1:8080/api/public/public/fund_em_lcx_rank"
 params = {
     "symbol": "850335.SI",
 }
